import pytest
import stk

from .case_data import CaseData

_complex = stk.ConstructedMolecule(
    topology_graph=stk.metal_complex.OctahedralDelta(
        metals=stk.BuildingBlock(
            smiles="[Fe+2]",
            functional_groups=(
                stk.SingleAtom(stk.Fe(0, charge=2)) for i in range(6)
            ),
            position_matrix=[[0, 0, 0]],
        ),
        ligands=stk.BuildingBlock(
            smiles="C1=NC(C=NBr)=CC=C1",
            functional_groups=[
                stk.SmartsFunctionalGroupFactory(
                    smarts="[#6]~[#7X2]~[#35]",
                    bonders=(1,),
                    deleters=(),
                ),
                stk.SmartsFunctionalGroupFactory(
                    smarts="[#6]~[#7X2]~[#6]",
                    bonders=(1,),
                    deleters=(),
                ),
            ],
        ),
        optimizer=stk.MCHammer(),
    ),
)


@pytest.fixture(
    scope="session",
    params=(
        lambda name: CaseData(
            molecule=stk.ConstructedMolecule(
                topology_graph=stk.cage.FourPlusSix(
                    building_blocks=(
                        stk.BuildingBlock(
                            smiles="NCCN",
                            functional_groups=[stk.PrimaryAminoFactory()],
                        ),
                        stk.BuildingBlock(
                            smiles="O=CC(C=O)C=O",
                            functional_groups=[stk.AldehydeFactory()],
                        ),
                    ),
                    optimizer=stk.MCHammer(),
                ),
            ),
            metal_atom_distances={},
            metal_centroid_angles={},
            min_centoid_distance=3.271852034747362,
            avg_centoid_distance=(5.328448699369716, 1.0456647551501264),
            radius_gyration=5.430081060350573,
            min_atom_atom_distance=1.0766369344893167,
            max_diameter=19.381435797835763,
            bonds={
                ("C", "N"): [
                    1.4368969294286886,
                    1.4031765805621368,
                    1.4368969294286882,
                    1.403176580562137,
                    1.4368969294286882,
                    1.4031765805621363,
                    1.4368969294286864,
                    1.4031765805621377,
                    1.4368969294286884,
                    1.4031765805621401,
                    1.4368969294286902,
                    1.4031765805621372,
                    1.6212241623194803,
                    1.640214343544766,
                    1.5991589337627785,
                    1.670870928292788,
                    1.868919401855132,
                    1.546101869901609,
                    1.625821187883433,
                    1.6726397776325337,
                    1.4727190881598273,
                    1.750679075919087,
                    1.8631095722036355,
                    1.67453470809124,
                ],
            },
            angles={
                ("C", "N", "C"): [
                    160.3425390064857,
                    156.52132802956265,
                    167.64887859141714,
                    173.29102723951823,
                    156.3116386480523,
                    149.94295464630287,
                    172.66568978944167,
                    161.66302809682907,
                    146.44044650760114,
                    154.00115755331592,
                    164.27115385717855,
                    171.59632667593783,
                ],
                ("C", "C", "N"): [
                    174.17863664380098,
                    172.8791271325533,
                    167.36918899011457,
                    160.5571921550806,
                    164.51031985889546,
                    146.00069284451894,
                    149.84607904829682,
                    174.23672412128906,
                    151.61295852329215,
                    162.55103899214512,
                    170.6051726561359,
                    164.55749249133396,
                    111.06913950132409,
                    114.09759412296773,
                    111.06913950132405,
                    114.09759412296783,
                    111.06913950132396,
                    114.0975941229678,
                    111.06913950132419,
                    114.09759412296773,
                    111.06913950132409,
                    114.0975941229677,
                    111.06913950132395,
                    114.09759412296789,
                ],
            },
            torsions={
                ("C", "C", "C", "N"): [
                    -162.18407696139795,
                    168.55415866695938,
                    126.32652970392458,
                    -68.65413904977524,
                    -109.47184005967121,
                    74.48389677557769,
                    -152.27017900825945,
                    97.16551096432134,
                    170.53547190219496,
                    -140.04278675241318,
                    -65.2628978614008,
                    84.39779472871611,
                    -128.63086497442578,
                    78.19521134230098,
                    152.59183046335494,
                    -159.0130863744335,
                    -83.20653930024079,
                    108.03710876254979,
                    -44.20416516837898,
                    144.20710984955355,
                    74.4821748312829,
                    -93.00118786718103,
                    -161.31619493231287,
                    -167.5361914314033,
                ],
                ("C", "N", "C", "C"): [
                    169.8742324213551,
                    39.98739059075721,
                    99.08897358624094,
                    -19.847141293942602,
                    163.36241458463212,
                    -170.50532658874926,
                    -125.44600733860793,
                    -67.10449461432859,
                    109.18156285202492,
                    133.19324619746885,
                    141.81397788066076,
                    100.8759628240879,
                    9.735853960068109,
                    174.3928741317648,
                    57.80110545778291,
                    132.085139362235,
                    171.90035820664278,
                    121.27561985942015,
                    139.9944831380974,
                    119.01101581672152,
                    -60.10668835819712,
                    30.34643483546436,
                    -152.69338933426872,
                    162.66061440894296,
                ],
                ("N", "C", "C", "N"): [
                    -60.00235934386044,
                    -60.00235934386033,
                    -60.00235934386041,
                    -60.00235934386035,
                    -60.002359343860384,
                    -60.00235934386033,
                ],
            },
            name=name,
        ),
        lambda name: CaseData(
            molecule=stk.ConstructedMolecule(
                topology_graph=stk.cage.M4L6TetrahedronSpacer(
                    building_blocks={
                        stk.BuildingBlock.init_from_molecule(
                            molecule=_complex,
                            functional_groups=[stk.BromoFactory()],
                        ): (0, 1, 2, 3),
                        stk.BuildingBlock(
                            smiles=("C1=CC(=CC=C1C2=CC=C(C=C2)Br)Br"),
                            functional_groups=[stk.BromoFactory()],
                        ): (4, 5, 6, 7, 8, 9),
                    },
                    optimizer=stk.MCHammer(),
                ),
            ),
            metal_atom_distances={
                (0, 40): 14.83956437672709,
                (0, 80): 14.454856249450632,
                (0, 120): 14.837980663967297,
                (40, 80): 14.593027908302588,
                (40, 120): 14.655844535316485,
                (80, 120): 14.599774709094143,
            },
            metal_centroid_angles={
                (0, 40): 110.77513231848364,
                (0, 80): 108.23994750583657,
                (0, 120): 110.55253117949731,
                (40, 80): 109.53287307949009,
                (40, 120): 108.32171727801348,
                (80, 120): 109.40454938926112,
            },
            min_centoid_distance=4.028829338000247,
            avg_centoid_distance=(8.93396048240581, 2.476075586273826),
            radius_gyration=9.270738924709828,
            min_atom_atom_distance=1.0694746499945305,
            max_diameter=39.77536160163197,
            bonds={
                ("C", "N"): [
                    1.3483660995252755,
                    1.3429161748830667,
                    1.290134284490674,
                    1.3483660995252773,
                    1.3429161748830745,
                    1.2901342844906758,
                    1.348366099525271,
                    1.3429161748830707,
                    1.2901342844906771,
                    1.3483660995252769,
                    1.3429161748830696,
                    1.2901342844906782,
                    1.3483660995252806,
                    1.3429161748830767,
                    1.2901342844906731,
                    1.3483660995252722,
                    1.3429161748830734,
                    1.2901342844906747,
                    1.348366099525275,
                    1.3429161748830727,
                    1.2901342844906725,
                    1.3483660995252784,
                    1.342916174883071,
                    1.2901342844906762,
                    1.3483660995252764,
                    1.3429161748830687,
                    1.290134284490682,
                    1.348366099525274,
                    1.3429161748830698,
                    1.290134284490679,
                    1.348366099525282,
                    1.3429161748830716,
                    1.2901342844906785,
                    1.3483660995252733,
                    1.3429161748830696,
                    1.290134284490678,
                    2.1790371587916035,
                    2.016172000487638,
                    2.14977655486645,
                    2.059813713772128,
                    2.1851710613200654,
                    2.2163099974542306,
                    1.952732994930903,
                    2.211828591943884,
                    2.3790161502264624,
                    2.2675320162232637,
                    2.0535274023133225,
                    1.8137967181072074,
                ],
                ("Fe", "N"): [
                    1.8764108353063726,
                    1.8360421948105805,
                    1.9178496791798203,
                    1.9183920856432721,
                    1.7925288456194501,
                    1.8592080852138002,
                    1.8764108353063762,
                    1.8360421948105847,
                    1.9178496791798196,
                    1.918392085643274,
                    1.7925288456194504,
                    1.8592080852137967,
                    1.8764108353063742,
                    1.8360421948105792,
                    1.9178496791798176,
                    1.9183920856432726,
                    1.7925288456194466,
                    1.8592080852137975,
                    1.8764108353063742,
                    1.8360421948105807,
                    1.9178496791798254,
                    1.918392085643271,
                    1.792528845619456,
                    1.859208085213797,
                ],
            },
            angles={
                ("Fe", "N", "C"): [
                    141.20366777814633,
                    95.77567529352805,
                    96.87820628809267,
                    168.19576476878075,
                    139.503416329865,
                    97.35320241957241,
                    99.47672420291326,
                    172.10977263059686,
                    143.70237517655167,
                    93.10220961078933,
                    96.83063581352766,
                    173.58544858734774,
                    141.20366777814627,
                    95.77567529352808,
                    96.87820628809258,
                    176.50620227830038,
                    139.50341632986485,
                    97.35320241957228,
                    99.4767242029134,
                    179.4679492398384,
                    143.70237517655173,
                    93.10220961078909,
                    96.83063581352756,
                    160.24469860320087,
                    141.20366777814647,
                    95.77567529352793,
                    96.87820628809267,
                    158.95538392489033,
                    139.50341632986485,
                    97.35320241957264,
                    99.47672420291339,
                    162.53103059986955,
                    143.7023751765517,
                    93.10220961078929,
                    96.8306358135275,
                    150.5383463051929,
                    141.2036677781463,
                    95.77567529352788,
                    96.87820628809239,
                    156.71245292156982,
                    139.5034163298648,
                    97.35320241957251,
                    99.47672420291293,
                    167.79690363149257,
                    143.70237517655144,
                    93.10220961078917,
                    96.83063581352745,
                    153.84930884631092,
                ],
                ("C", "N", "C"): [
                    122.78334903263814,
                    72.71905917978005,
                    122.7833490326382,
                    72.95642305012208,
                    122.7833490326382,
                    89.1276358172831,
                    122.7833490326382,
                    86.60581068678198,
                    122.78334903263843,
                    80.49416231102528,
                    122.78334903263843,
                    70.13693120400939,
                    122.78334903263813,
                    64.13241244795927,
                    122.7833490326381,
                    87.1185279298224,
                    122.7833490326382,
                    78.3588067767288,
                    122.78334903263833,
                    63.74249455892237,
                    122.78334903263824,
                    91.58408517006197,
                    122.78334903263861,
                    88.86355756733705,
                ],
                ("N", "Fe", "N"): [
                    101.59752223506658,
                    91.12949542908507,
                    171.6380918759749,
                    90.93670777140734,
                    92.10258153469162,
                    89.24116838193918,
                    77.61453278484748,
                    167.18843890052486,
                    78.4778010898487,
                    97.17290159755842,
                    87.85692566261923,
                    167.69388453013482,
                    90.36950365206684,
                    79.56838507722914,
                    103.95445775455131,
                    101.5975222350664,
                    91.12949542908507,
                    171.638091875975,
                    90.93670777140721,
                    92.10258153469157,
                    89.2411683819391,
                    77.61453278484755,
                    167.1884389005252,
                    78.47780108984861,
                    97.17290159755831,
                    87.85692566261919,
                    167.69388453013465,
                    90.36950365206708,
                    79.56838507722928,
                    103.95445775455151,
                    101.59752223506652,
                    91.12949542908534,
                    171.63809187597488,
                    90.93670777140746,
                    92.10258153469152,
                    89.24116838193899,
                    77.61453278484753,
                    167.1884389005248,
                    78.47780108984865,
                    97.17290159755814,
                    87.85692566261933,
                    167.69388453013462,
                    90.36950365206674,
                    79.56838507722924,
                    103.95445775455138,
                    101.59752223506662,
                    91.12949542908521,
                    171.63809187597474,
                    90.93670777140738,
                    92.10258153469171,
                    89.24116838193918,
                    77.61453278484726,
                    167.18843890052486,
                    78.47780108984847,
                    97.17290159755844,
                    87.85692566261932,
                    167.6938845301346,
                    90.36950365206697,
                    79.56838507722885,
                    103.9544577545514,
                ],
                ("N", "C", "C"): [
                    121.36714487021132,
                    122.9886079540146,
                    117.84289820217812,
                    122.29822496997883,
                    138.7948108941765,
                    103.94888492711678,
                    121.36714487021148,
                    122.98860795401478,
                    117.84289820217764,
                    122.29822496997878,
                    139.66298487482314,
                    102.41799221097163,
                    121.36714487021163,
                    122.98860795401475,
                    117.84289820217766,
                    122.29822496997859,
                    121.98481324778493,
                    120.62859990280812,
                    121.36714487021132,
                    122.98860795401463,
                    117.84289820217796,
                    122.298224969979,
                    129.1224982598148,
                    114.11868849454079,
                    121.36714487021115,
                    122.98860795401485,
                    117.84289820217748,
                    122.29822496997878,
                    132.12240082828205,
                    110.14345867481188,
                    121.3671448702115,
                    122.98860795401495,
                    117.84289820217761,
                    122.29822496997859,
                    140.09553468220852,
                    98.44651916257048,
                    121.36714487021135,
                    122.98860795401465,
                    117.84289820217779,
                    122.29822496997895,
                    134.3596158122187,
                    104.93379815686366,
                    121.36714487021153,
                    122.98860795401468,
                    117.84289820217764,
                    122.29822496997875,
                    123.83335712032464,
                    118.03457215596175,
                    121.36714487021155,
                    122.98860795401492,
                    117.84289820217761,
                    122.29822496997858,
                    151.84731595258708,
                    88.21094855857741,
                    121.36714487021145,
                    122.9886079540148,
                    117.8428982021777,
                    122.298224969979,
                    131.19363517860603,
                    106.96311317606273,
                    121.36714487021143,
                    122.98860795401475,
                    117.84289820217757,
                    122.29822496997895,
                    128.42546358536435,
                    114.04854052917774,
                    121.36714487021122,
                    122.98860795401517,
                    117.84289820217744,
                    122.29822496997849,
                    140.76999198267845,
                    97.22260720852356,
                ],
            },
            torsions={
                ("Fe", "N", "C", "C"): [
                    172.82953973509007,
                    4.509190385359167,
                    -175.49141054221286,
                    -4.423216911553739,
                    33.90191354399271,
                    -143.69766131212103,
                    171.3366726902218,
                    5.660970243072076,
                    -174.33963068449935,
                    -5.695649224097604,
                    -17.83544767062803,
                    172.77698592067736,
                    170.2561196668607,
                    5.759236977156449,
                    -174.2413639504153,
                    -6.010081871773075,
                    161.60348214771338,
                    -13.57639391625812,
                    172.8295397350901,
                    4.509190385358911,
                    -175.49141054221283,
                    -4.423216911554133,
                    -137.75728710518703,
                    47.155816462038324,
                    171.33667269022177,
                    5.660970243072195,
                    -174.33963068449938,
                    -5.695649224097563,
                    -86.67572536553531,
                    101.99516693051906,
                    170.2561196668612,
                    5.75923697715605,
                    -174.24136395041535,
                    -6.010081871773016,
                    -60.810316047928296,
                    145.2393856739387,
                    172.82953973508964,
                    4.509190385358867,
                    -175.4914105422125,
                    -4.423216911553921,
                    92.73488826948302,
                    -111.92607807512948,
                    171.33667269022175,
                    5.66097024307217,
                    -174.33963068449927,
                    -5.695649224097682,
                    123.93078197129601,
                    -67.32190911046922,
                    170.2561196668606,
                    5.759236977156139,
                    -174.24136395041486,
                    -6.010081871773324,
                    -53.65426036960846,
                    153.36831344166504,
                    172.82953973508992,
                    4.509190385358778,
                    -175.49141054221266,
                    -4.423216911554314,
                    101.60411504668193,
                    -105.66034965492892,
                    171.33667269022177,
                    5.660970243072315,
                    -174.33963068449924,
                    -5.6956492240975605,
                    -113.96071330971019,
                    77.60124797920858,
                    170.25611966686097,
                    5.759236977156507,
                    -174.24136395041526,
                    -6.010081871773018,
                    -76.4770541185234,
                    133.21775780729618,
                ],
                ("C", "N", "Fe", "N"): [
                    -179.82189351645778,
                    -90.36484514527638,
                    96.46064740975558,
                    -2.4901402125148526,
                    101.51125685311445,
                    6.031666466383421,
                    -21.661856517646402,
                    1.206061421482117,
                    173.8699605669052,
                    -179.53718947513303,
                    -163.31435613717736,
                    -87.34441273650879,
                    84.46309197519436,
                    -83.3132376923407,
                    118.52860591730669,
                    -5.8766504995735,
                    83.58039787160789,
                    -89.59410957336017,
                    171.45510280436943,
                    -84.54350013000129,
                    -84.96570555334375,
                    177.52084026483723,
                    -161.85123147217195,
                    95.82467302468699,
                    102.79162681223414,
                    -84.54447404234278,
                    94.97392768088618,
                    111.19676101884183,
                    80.78789764511416,
                    -107.40459764318271,
                    175.2770063848163,
                    17.118849994463698,
                    -179.7920532942164,
                    -89.68920630978087,
                    106.42757137445666,
                    -112.65922853737358,
                    7.341057650983754,
                    23.563890988939427,
                    3.7509620198963014,
                    175.55846673159945,
                    171.56650323795884,
                    13.408346847606236,
                    -7.128154148793318,
                    82.97469283564222,
                    -80.90852948012025,
                    -80.54544544398475,
                    175.33056101496095,
                    149.82731728080736,
                    100.91512413789944,
                    -87.27737115039744,
                    95.94087784095333,
                    -62.21727854939928,
                    -179.74421565038784,
                    170.45524554379824,
                    -64.3226121060291,
                    8.175422150339653,
                    -149.98273424001295,
                    -7.936710938684726,
                    68.13115004065716,
                    -168.44660564708337,
                    -179.82189351645758,
                    -90.36484514527625,
                    96.46064740975656,
                    -2.4901402125147665,
                    101.51125685311473,
                    6.031666466383606,
                    -169.66703431538207,
                    1.2060614214823486,
                    173.86996056690526,
                    -179.53718947513383,
                    -92.71833152586412,
                    -87.34441273650911,
                    84.46309197519466,
                    -83.3132376923408,
                    -36.070155864822645,
                    -5.876650499573468,
                    83.58039787160787,
                    -89.59410957335935,
                    171.45510280436935,
                    -84.54350013000118,
                    -84.96570555334357,
                    177.52084026483752,
                    -161.851231472171,
                    95.82467302468714,
                    102.79162681223417,
                    -84.54447404234291,
                    94.97392768088618,
                    -178.2072143698441,
                    80.7878976451131,
                    -107.40459764318314,
                    175.2770063848164,
                    -137.47991178766546,
                    -179.7920532942163,
                    -89.68920630978052,
                    106.4275713744565,
                    99.3355936648908,
                    7.341057650983784,
                    94.1599156002535,
                    3.7509620198959714,
                    175.55846673159974,
                    171.5665032379591,
                    -141.19041493452275,
                    -7.12815414879337,
                    82.9746928356424,
                    -80.90852948012058,
                    -80.54544544398472,
                    175.33056101496084,
                    1.8221394830718474,
                    100.91512413789899,
                    -87.27737115039724,
                    95.94087784095335,
                    143.18395966847152,
                    -179.74421565038813,
                    22.45006774606334,
                    6.273412505284997,
                    8.175422150339413,
                    55.41850397785758,
                    -7.936710938684346,
                    -79.87402775707852,
                    -97.85058103576948,
                    -179.82189351645735,
                    -90.36484514527606,
                    96.46064740975619,
                    -2.490140212514434,
                    101.51125685311494,
                    6.03166646638342,
                    -18.42536772544916,
                    1.2060614214822514,
                    173.86996056690518,
                    -179.53718947513323,
                    69.32317944891855,
                    -87.34441273650863,
                    84.46309197519442,
                    -83.31323769234076,
                    -4.916942594941864,
                    -5.876650499573317,
                    83.58039787160794,
                    -89.5941095733598,
                    171.45510280436957,
                    -84.54350013000105,
                    -84.96570555334401,
                    177.52084026483723,
                    -161.8512314721719,
                    95.82467302468689,
                    102.79162681223418,
                    -84.54447404234291,
                    94.97392768088615,
                    -16.165703395062096,
                    80.78789764511427,
                    -107.4045976431827,
                    175.2770063848163,
                    -106.32669851778479,
                    -179.79205329421632,
                    -89.68920630978084,
                    106.42757137445736,
                    -109.42273974517659,
                    7.341057650983845,
                    -103.7985734249644,
                    3.75096201989672,
                    175.55846673159976,
                    171.5665032379582,
                    -110.03720166464292,
                    -7.1281541487934135,
                    82.97469283564206,
                    -80.90852948011975,
                    -80.54544544398475,
                    175.33056101496086,
                    153.06380607300463,
                    100.91512413789958,
                    -87.27737115039739,
                    95.9408778409533,
                    174.3371729383522,
                    -179.74421565038764,
                    173.69173433599556,
                    168.31492348006702,
                    8.175422150339706,
                    86.5717172477386,
                    -7.9367109386845955,
                    71.36763883285431,
                    64.1909299390126,
                    -179.82189351645775,
                    -90.36484514527633,
                    96.46064740975677,
                    -2.4901402125147185,
                    101.51125685311467,
                    6.031666466383708,
                    -26.093696777822053,
                    1.2060614214823884,
                    173.8699605669052,
                    -179.53718947513408,
                    -24.7883596889134,
                    -87.3444127365087,
                    84.46309197519446,
                    -83.31323769234079,
                    18.14436556690972,
                    -5.876650499573458,
                    83.58039787160797,
                    -89.59410957335895,
                    171.45510280436957,
                    -84.54350013000105,
                    -84.9657055533436,
                    177.52084026483735,
                    -161.85123147217223,
                    95.82467302468733,
                    102.79162681223444,
                    -84.54447404234274,
                    94.9739276808862,
                    -110.27724253289311,
                    80.78789764511484,
                    -107.40459764318202,
                    175.27700638481622,
                    -83.26539035593329,
                    -179.79205329421634,
                    -89.68920630978064,
                    106.42757137445771,
                    -117.09106879754937,
                    7.3410576509838235,
                    162.0898874372045,
                    3.75096201989652,
                    175.55846673159968,
                    171.566503237958,
                    -86.97589350279152,
                    -7.128154148793488,
                    82.9746928356422,
                    -80.90852948011946,
                    -80.54544544398479,
                    175.33056101496084,
                    145.3954770206316,
                    100.91512413789965,
                    -87.2773711503972,
                    95.94087784095338,
                    -162.60151889979613,
                    -179.74421565038787,
                    166.023405283622,
                    74.2033843422359,
                    8.175422150339644,
                    109.63302540959015,
                    -7.936710938684729,
                    63.69930978048155,
                    -29.920609198818482,
                ],
                ("C", "N", "C", "C"): [
                    -179.99940642650964,
                    -7.354081646684983e-06,
                    0.00019205635405409666,
                    169.86260588480096,
                    5.0066883215145035,
                    -172.59288653459922,
                    -179.9994064265099,
                    -7.354081344971243e-06,
                    0.00019205635385048786,
                    176.60326601381672,
                    -1.084086744324282,
                    -170.4716531530189,
                    -179.99940642650978,
                    -7.3540815074325005e-06,
                    0.00019205635389445312,
                    171.60743076861237,
                    3.2850527502579676,
                    -171.89482331371354,
                    -179.99940642651,
                    -7.354081737661426e-06,
                    0.00019205635428395064,
                    175.31444484576193,
                    46.52051576282963,
                    -128.56638066994503,
                    -179.99940642650995,
                    -7.354081546887316e-06,
                    0.00019205635403487362,
                    174.84297788704578,
                    0.2319514949391895,
                    -171.09715620900644,
                    -179.99940642650975,
                    -7.3540811337717195e-06,
                    0.00019205635364982963,
                    -170.70998359353544,
                    -9.992194296193816,
                    -163.94249257432685,
                    -179.99940642651012,
                    -7.354081446355411e-06,
                    0.00019205635394076522,
                    166.0665501329864,
                    65.55405756446511,
                    -139.1069087801474,
                    -179.99940642650998,
                    -7.354081407634842e-06,
                    0.00019205635400637428,
                    158.02371914600317,
                    11.02408486365957,
                    179.77139378189435,
                    -179.99940642651015,
                    -7.35408115233866e-06,
                    0.00019205635388376587,
                    -156.54407217746004,
                    29.57978283151167,
                    -123.39764335721486,
                    -179.99940642651,
                    -7.354081442049103e-06,
                    0.00019205635389920317,
                    162.01914021137327,
                    65.53997938617813,
                    -141.72448531543273,
                    -179.9994064265099,
                    -7.354081456373191e-06,
                    0.00019205635410374884,
                    179.47977806548437,
                    41.14620688231028,
                    -127.29183182877095,
                    -179.99940642650978,
                    -7.3540815352829845e-06,
                    0.00019205635417232603,
                    -160.41327207915123,
                    26.791018216373388,
                    -123.51416985780705,
                ],
                ("N", "C", "C", "C"): [
                    -0.0003425392087856527,
                    -6.587853727084077e-06,
                    -179.99793032897958,
                    -177.37987742534952,
                    178.22501233174071,
                    -0.00034253920884789617,
                    -6.587853898173896e-06,
                    -179.99793032897966,
                    -168.3309510389253,
                    172.29919652711354,
                    -0.00034253920861670697,
                    -6.587853871159772e-06,
                    -179.99793032897966,
                    -175.33594755474851,
                    175.4059710802745,
                    -0.0003425392092146874,
                    -6.587853555994165e-06,
                    -179.99793032897935,
                    -174.98564673431676,
                    175.74276405517233,
                    -0.0003425392090679703,
                    -6.587853612273663e-06,
                    -179.99793032897963,
                    -170.8414291210585,
                    172.7792050992424,
                    -0.00034253920877856756,
                    -6.587853980623442e-06,
                    -179.99793032897972,
                    -150.75878124827406,
                    161.5332802707644,
                    -0.00034253920889235794,
                    -6.5878538126289565e-06,
                    -179.9979303289799,
                    153.2013798696214,
                    -160.50812960217036,
                    -0.0003425392090101734,
                    -6.587853877913293e-06,
                    -179.9979303289797,
                    168.83200589636627,
                    -169.4944968027022,
                    -0.0003425392089212545,
                    -6.587854243871168e-06,
                    -179.99793032897995,
                    -149.48043223498257,
                    166.1334677896988,
                    -0.0003425392088812416,
                    -6.5878537450935026e-06,
                    -179.9979303289794,
                    150.65874062798088,
                    -157.32175677821888,
                    -0.0003425392090968689,
                    -6.587853886917983e-06,
                    -179.99793032897975,
                    -168.1896514189013,
                    169.89076574212373,
                    -0.000342539209123824,
                    -6.587853842738547e-06,
                    -179.9979303289797,
                    -146.66193245325528,
                    159.49475475882676,
                ],
                ("N", "C", "C", "N"): [
                    0.0014611448335623994,
                    0.0014611448340874195,
                    0.0014611448337984155,
                    0.0014611448340780579,
                    0.001461144833952478,
                    0.0014611448340897078,
                    0.001461144833953777,
                    0.0014611448340717441,
                    0.001461144834248942,
                    0.001461144834333099,
                    0.0014611448338908222,
                    0.0014611448337246275,
                ],
                ("C", "N", "C", "H"): [
                    -179.99974123337225,
                    -10.13588850744174,
                    -179.9997412333726,
                    -3.3952283784255584,
                    -179.99974123337216,
                    -8.391063623630023,
                    -179.99974123337233,
                    -4.684049546480267,
                    -179.99974123337242,
                    -5.1555165051966085,
                    -179.99974123337273,
                    9.291522014222231,
                    -179.99974123337233,
                    -13.93194425925627,
                    -179.9997412333724,
                    -21.97477524623898,
                    -179.99974123337228,
                    23.45743343029753,
                    -179.99974123337245,
                    -17.97935418086885,
                    -179.99974123337245,
                    -0.5187163267581315,
                    -179.99974123337236,
                    19.58823352860615,
                ],
            },
            name=name,
        ),
        lambda name: CaseData(
            molecule=stk.ConstructedMolecule(
                topology_graph=stk.cage.M6L12Cube(
                    building_blocks=(
                        stk.BuildingBlock(
                            smiles="[Pd+2]",
                            functional_groups=(
                                stk.SingleAtom(stk.Pd(0, charge=2))
                                for i in range(4)
                            ),
                            position_matrix=[[0, 0, 0]],
                        ),
                        stk.BuildingBlock(
                            smiles=(
                                "C1=NC=CC(C2=CC=CC(C3=C" "C=NC=C3)=C2)=C1"
                            ),
                            functional_groups=[
                                stk.SmartsFunctionalGroupFactory(
                                    smarts="[#6]~[#7X2]~[#6]",
                                    bonders=(1,),
                                    deleters=(),
                                ),
                            ],
                        ),
                    ),
                    optimizer=stk.Collapser(),
                ),
            ),
            metal_atom_distances={
                (0, 1): 10.896944441369676,
                (0, 2): 15.412420828743615,
                (0, 3): 10.898227238903015,
                (0, 4): 10.89758581086942,
                (0, 5): 10.89758581086942,
                (1, 2): 10.898227013424108,
                (1, 3): 15.412420828751983,
                (1, 4): 10.89758569813956,
                (1, 5): 10.89758569813956,
                (2, 3): 10.899510587395719,
                (2, 4): 10.898868771096192,
                (2, 5): 10.898868771096192,
                (3, 4): 10.898868883845243,
                (3, 5): 10.898868883845243,
                (4, 5): 15.412420799323275,
            },
            metal_centroid_angles={
                (0, 1): 89.97683228781653,
                (0, 2): 179.97682458236295,
                (0, 3): 89.99999891399814,
                (0, 4): 89.98841325868929,
                (0, 5): 89.98841325868929,
                (1, 2): 89.99999229454916,
                (1, 3): 179.97683120183706,
                (1, 4): 89.988409950303,
                (1, 5): 89.988409950303,
                (2, 3): 90.02317650363617,
                (2, 4): 90.01158205422921,
                (2, 5): 90.01158205422921,
                (3, 4): 90.0115853652926,
                (3, 5): 90.0115853652926,
                (4, 5): 179.96722969198316,
            },
            min_centoid_distance=6.383408826308891,
            avg_centoid_distance=(8.60220669009043, 1.4865651154918351),
            radius_gyration=8.729709948310644,
            min_atom_atom_distance=0.44643102631473996,
            max_diameter=33.73047877339638,
            bonds={
                ("C", "N"): [
                    1.353058965423603,
                    1.3451283016975855,
                    1.3465440099589545,
                    1.3435751961267794,
                    1.353058965423606,
                    1.3451283016975866,
                    1.3465440099589543,
                    1.3435751961267801,
                    1.3530589654236038,
                    1.3451283016975855,
                    1.3465440099589518,
                    1.3435751961267812,
                    1.3530589654236038,
                    1.3451283016975877,
                    1.3465440099589547,
                    1.3435751961267768,
                    1.3530589654236043,
                    1.3451283016975895,
                    1.3465440099589574,
                    1.3435751961267766,
                    1.3530589654236056,
                    1.34512830169759,
                    1.3465440099589556,
                    1.3435751961267788,
                    1.3530589654236065,
                    1.3451283016975861,
                    1.3465440099589556,
                    1.343575196126776,
                    1.3530589654236065,
                    1.3451283016975881,
                    1.3465440099589545,
                    1.3435751961267786,
                    1.3530589654236032,
                    1.3451283016975886,
                    1.3465440099589578,
                    1.3435751961267792,
                    1.3530589654236083,
                    1.3451283016975855,
                    1.3465440099589543,
                    1.3435751961267772,
                    1.353058965423604,
                    1.3451283016975852,
                    1.3465440099589534,
                    1.3435751961267814,
                    1.3530589654236045,
                    1.3451283016975875,
                    1.3465440099589556,
                    1.3435751961267772,
                ],
                ("N", "Pd"): [
                    1.1462870375279308,
                    1.1475305900353587,
                    1.1469088095181883,
                    1.1469088095181912,
                    1.161990472392297,
                    1.147530425643655,
                    1.146908753463117,
                    1.1469087534631166,
                    1.1626430874302047,
                    1.1481571311671641,
                    1.147535254936645,
                    1.1475352549366422,
                    1.162643252571796,
                    1.163868059705465,
                    1.1475353110970166,
                    1.147535311097016,
                    1.1623167164933919,
                    1.1635414322797313,
                    1.1623166098662991,
                    1.1635415389134378,
                    1.1623167164933907,
                    1.1635414322797317,
                    1.1623166098662991,
                    1.1635415389134378,
                ],
            },
            angles={
                ("Pd", "N", "C"): [
                    145.3364161204098,
                    92.71566433965049,
                    145.35355533585238,
                    92.69066373740844,
                    145.34750870396223,
                    92.70174983337294,
                    145.3424706652124,
                    92.70457102697569,
                    92.9848316785696,
                    143.6882660203896,
                    145.35355657996374,
                    92.69066192199989,
                    145.34247379868617,
                    92.70456674767497,
                    145.347511188711,
                    92.70174591755409,
                    93.02895476171841,
                    143.65593509762243,
                    145.32224414757718,
                    92.73632319173113,
                    145.31113736931889,
                    92.75024650225262,
                    145.3161777521393,
                    92.74742165640887,
                    93.02895634265737,
                    143.6559339386069,
                    93.00289339845105,
                    143.67503539976832,
                    145.31617461662046,
                    92.74742593332886,
                    145.31113488253465,
                    92.75025041580395,
                    93.0054944468834,
                    143.67448567558878,
                    92.98224296239863,
                    143.68880992718314,
                    93.00830159119344,
                    143.66971673834388,
                    92.97944812961104,
                    143.69356020470838,
                    93.00829939731649,
                    143.66971817172484,
                    92.97945032030039,
                    143.6935587749178,
                    93.00549700075612,
                    143.67448363012494,
                    92.98224041109339,
                    143.68881196998996,
                ],
                ("C", "N", "C"): [
                    118.19129090481385,
                    120.25508586967823,
                    118.1912909048137,
                    120.25508586967857,
                    118.19129090481388,
                    120.25508586967835,
                    118.19129090481366,
                    120.25508586967821,
                    118.19129090481367,
                    120.25508586967818,
                    118.1912909048137,
                    120.25508586967823,
                    118.19129090481375,
                    120.25508586967818,
                    118.19129090481353,
                    120.25508586967831,
                    118.19129090481373,
                    120.25508586967825,
                    118.19129090481367,
                    120.25508586967828,
                    118.19129090481375,
                    120.25508586967838,
                    118.1912909048137,
                    120.25508586967831,
                ],
                ("N", "Pd", "N"): [
                    146.05077203329736,
                    85.11751169319207,
                    85.11751169319201,
                    147.47168093004834,
                    85.51711582194356,
                    85.51711582195776,
                    85.10356916634119,
                    85.10356916634086,
                    148.9898489867429,
                    85.54406044093516,
                    85.54406044093523,
                    146.05076337936742,
                    148.94063169866487,
                    85.9029392004031,
                    85.88930722388662,
                    148.94063169866487,
                    85.90293920041705,
                    85.88930722388649,
                    85.10356771364772,
                    85.10356771363362,
                    147.57180639857145,
                    85.54405917253885,
                    85.54405917253868,
                    85.13206384277788,
                    85.13206384277795,
                    85.52969470280868,
                    85.52969470280857,
                    146.15257104730188,
                    85.88930937763236,
                    85.87571674231248,
                    85.88930937761859,
                    85.87571674231253,
                    146.0507542460134,
                    148.94063170205763,
                    148.9406317020578,
                    146.15258017587263,
                ],
                ("N", "C", "C"): [
                    121.5534906677226,
                    122.20332532342933,
                    122.45456305486576,
                    118.34402198600888,
                    121.5534906677226,
                    122.20332532342938,
                    122.45456305486576,
                    118.3440219860084,
                    121.55349066772247,
                    122.20332532342918,
                    122.45456305486589,
                    118.34402198600843,
                    121.5534906677227,
                    122.20332532342941,
                    122.45456305486576,
                    118.34402198600894,
                    121.55349066772266,
                    122.20332532342931,
                    122.45456305486566,
                    118.34402198600894,
                    121.5534906677226,
                    122.20332532342935,
                    122.45456305486579,
                    118.34402198600873,
                    121.55349066772243,
                    122.20332532342935,
                    122.45456305486576,
                    118.34402198600888,
                    121.55349066772266,
                    122.20332532342948,
                    122.45456305486586,
                    118.34402198600868,
                    121.55349066772268,
                    122.2033253234291,
                    122.45456305486573,
                    118.34402198600858,
                    121.55349066772256,
                    122.20332532342921,
                    122.45456305486582,
                    118.34402198600868,
                    121.5534906677226,
                    122.20332532342935,
                    122.45456305486583,
                    118.3440219860085,
                    121.5534906677226,
                    122.20332532342935,
                    122.45456305486593,
                    118.34402198600871,
                ],
            },
            torsions={
                ("Pd", "N", "C", "C"): [
                    -150.4154059000122,
                    163.67441178347977,
                    -150.37677213869708,
                    163.66209621087182,
                    -150.39954395378984,
                    163.6711220405506,
                    -150.39263169379097,
                    163.66538225321577,
                    -164.7009925945828,
                    153.57871485868606,
                    -150.37676933211472,
                    163.66209531660206,
                    -150.39262580717937,
                    163.6653806044848,
                    -150.39953717631272,
                    163.67111965231177,
                    -164.72286976688872,
                    153.6413964043478,
                    -150.4473052217879,
                    163.68458899306444,
                    -150.46315025411545,
                    163.68787886215839,
                    -150.4700746999408,
                    163.69362602724752,
                    -164.72287055078775,
                    153.64139864852854,
                    -164.70994774314025,
                    153.60438501371547,
                    -150.47008057315244,
                    163.69362767513792,
                    -150.46315701775086,
                    163.687881249329,
                    -164.7147691600345,
                    153.61357653620703,
                    -164.6961928591633,
                    153.5695614849389,
                    -164.7090979131514,
                    153.60657336895784,
                    -164.70183924722951,
                    153.57653305805795,
                    -164.70909637208274,
                    153.60656954703143,
                    -164.70184078741656,
                    153.57653687980556,
                    -164.71476997303765,
                    153.61357945891274,
                    -164.69619204829434,
                    153.56955856400685,
                ],
                ("C", "N", "Pd", "N"): [
                    -52.023697298649715,
                    21.699200044816045,
                    -125.74659464211479,
                    -52.0554770743546,
                    153.80020282338373,
                    -125.77518598187828,
                    80.06133619985025,
                    21.6960113712456,
                    -132.46150978829857,
                    153.79962200110748,
                    -132.47748065542677,
                    80.07672465764242,
                    -153.65877361989558,
                    132.73002997657724,
                    -80.04757721637219,
                    -52.05547938326251,
                    153.80020286536376,
                    23.064139247026052,
                    -131.09337699259535,
                    -127.14332427503561,
                    78.6932035945271,
                    48.97976795495558,
                    -24.6314284485716,
                    122.59096435847897,
                    -125.78245977679221,
                    21.671505628082368,
                    21.674699665408177,
                    -132.48877815286332,
                    -125.75387427604096,
                    80.08860456441487,
                    80.07322012094615,
                    -132.47281447417933,
                    -153.6576259872287,
                    -80.00076565110801,
                    132.68551367665071,
                    -153.65830590157975,
                    48.95908451875478,
                    -127.12884532319063,
                    78.64859347792681,
                    23.165685039686913,
                    -131.05090747384213,
                    48.92926738852439,
                    122.5861277246451,
                    -24.727592947596207,
                    -52.02627750781451,
                    -52.05289710281819,
                    153.78958173763766,
                    153.810244673914,
                    -153.6694005311077,
                    -78.63442949554072,
                    131.3465958201631,
                    -153.64767204740934,
                    48.998495227550045,
                    131.3180286802176,
                    -26.06629937243698,
                    -78.63145315193209,
                    124.00880254606055,
                    48.94033189315578,
                    123.97530292872278,
                    -26.04367175557344,
                    -153.64700322651748,
                    131.31802573791893,
                    -78.66299957778838,
                    -153.6700808869437,
                    48.970171651193404,
                    -78.63443231434874,
                    123.9752977125674,
                    131.31370009533705,
                    -26.040130233793214,
                    48.96867188070658,
                    -26.066299154857003,
                    123.95267552943568,
                    21.67149897017749,
                    -125.78245773670662,
                    -125.75387755423995,
                    80.08860620613868,
                    21.674692526230338,
                    -132.48877960420697,
                    -132.47281878119625,
                    80.07322451191962,
                    -153.6576260286505,
                    132.68551803423546,
                    -80.00077009153658,
                    -51.997462168305745,
                    153.7991379768883,
                    23.16567813229571,
                    -131.05090870526027,
                    -127.12884880680001,
                    78.64859490287598,
                    48.92926919615123,
                    -24.727586740962828,
                    122.58612513326514,
                    21.77439278960927,
                    -125.76931712622056,
                    -125.74073765033152,
                    80.0426755121125,
                    21.777566975827256,
                    -132.44498931449678,
                    -132.42900706519674,
                    80.02728301897348,
                    132.6810094155372,
                    -79.99762121869672,
                    23.143257146829296,
                    -131.07930405205326,
                    -127.10641743033305,
                    78.67699005613794,
                    -24.70160016412828,
                    122.61976920163778,
                    -51.99494566405491,
                    -51.96822501044932,
                    153.80921869922668,
                    153.7884674983891,
                    131.31369785374284,
                    -78.6600207658817,
                    -78.66299721602995,
                    123.95267473131548,
                    131.34226489198522,
                    -26.017479410022126,
                    -26.040134871297788,
                    123.98614650907767,
                    -78.63145078809187,
                    131.3422678315288,
                    131.34659358189884,
                    -26.04367639118502,
                    -78.66001794858028,
                    123.98615172228948,
                    124.00880175004527,
                    -26.017479630334073,
                    -52.052900593679674,
                    -52.02628443433404,
                    153.81024343522864,
                    153.78958316669895,
                    -153.64700460697915,
                    -153.67007950614166,
                    48.97017619185099,
                    48.968667340366274,
                    -153.66939902717587,
                    -153.64767355042574,
                    48.99849612044402,
                    48.940330999740254,
                    -51.968221530535786,
                    -51.99493875296791,
                    153.78846873350307,
                    153.80921727058168,
                ],
                ("C", "N", "C", "C"): [
                    -9.522309657420727e-05,
                    0.0025246278671328224,
                    -0.0015368971508784505,
                    0.002584298224398102,
                    -9.52230966722856e-05,
                    0.0025246278673199786,
                    -0.00153689715077464,
                    0.0025842982241423345,
                    -9.522309671790354e-05,
                    0.0025246278674934406,
                    -0.001536897150638974,
                    0.002584298223964221,
                    -9.522309654569603e-05,
                    0.0025246278672252575,
                    -0.0015368971508088513,
                    0.002584298224265653,
                    -9.522309643735347e-05,
                    0.002524627867064338,
                    -0.0015368971512323703,
                    0.0025842982246584156,
                    -9.522309657420704e-05,
                    0.0025246278672537833,
                    -0.0015368971509492418,
                    0.002584298224377541,
                    -9.522309658104985e-05,
                    0.0025246278672811755,
                    -0.0015368971507309958,
                    0.002584298224233678,
                    -9.52230965399938e-05,
                    0.002524627867254923,
                    -0.0015368971506413355,
                    0.0025842982241286385,
                    -9.522309634269601e-05,
                    0.00252462786705977,
                    -0.0015368971508607594,
                    0.00258429822416516,
                    -9.522309658903231e-05,
                    0.0025246278674420893,
                    -0.0015368971508702002,
                    0.002584298224247376,
                    -9.522309663921279e-05,
                    0.0025246278672903075,
                    -0.0015368971506802625,
                    0.0025842982240509953,
                    -9.522309643849378e-05,
                    0.0025246278672081297,
                    -0.0015368971505858927,
                    0.0025842982239687854,
                ],
                ("N", "C", "C", "C"): [
                    -0.004104968945188446,
                    -0.000776501588310222,
                    -0.000765564372668298,
                    -0.0014392589680501313,
                    -0.004104968945313624,
                    -0.0007765015883803146,
                    -0.0007655643727098696,
                    -0.0014392589676829172,
                    -0.004104968945617624,
                    -0.0007765015883236585,
                    -0.0007655643725897747,
                    -0.001439258967715452,
                    -0.004104968945339422,
                    -0.0007765015884060139,
                    -0.0007655643726221057,
                    -0.0014392589679804101,
                    -0.004104968945197716,
                    -0.0007765015884457308,
                    -0.0007655643723634239,
                    -0.001439258968203527,
                    -0.004104968945322901,
                    -0.0007765015884176931,
                    -0.0007655643726498196,
                    -0.0014392589678827981,
                    -0.004104968945415348,
                    -0.0007765015883855709,
                    -0.0007655643726498223,
                    -0.001439258968031541,
                    -0.004104968945347805,
                    -0.000776501588477277,
                    -0.0007655643727699229,
                    -0.0014392589678734985,
                    -0.004104968945120059,
                    -0.0007765015887208398,
                    -0.0007655643725389565,
                    -0.0014392589677340532,
                    -0.004104968945585162,
                    -0.0007765015885088154,
                    -0.0007655643725990097,
                    -0.0014392589678223708,
                    -0.004104968945324643,
                    -0.0007765015883689258,
                    -0.0007655643727791601,
                    -0.0014392589676131952,
                    -0.004104968945286968,
                    -0.0007765015886390666,
                    -0.0007655643728114937,
                    -0.0014392589676131987,
                ],
            },
            name=name,
        ),
    ),
)
def case_data(request) -> CaseData:
    return request.param(
        f"{request.fixturename}{request.param_index}",
    )
